==> vdocipher_flutter-2.2.0.tar.gz: lib/src/views/vdo_styled_player.dart <==
import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';
import 'package:vdocipher_flutter/src/views/playback_event.dart';
import 'package:vdocipher_flutter/src/views/utils.dart';
import 'package:vdocipher_flutter/vdocipher_flutter.dart';

class VdoStyledPlayer extends StatefulWidget {
  final EmbedInfo embedInfo;
  final double aspectRatio;
  final Function(VdoError vdoError)? onError;
  final PlaybackEventListener? playbackEventListener;
  final Function(bool isFullscreen)? onFullscreenChange;
  final Function(VdoPlayerController vdoPlayerController) onPlayerCreated;
  final bool controls;

  VdoStyledPlayer(
      {Key? key,
      required this.embedInfo,
      required this.onPlayerCreated,
      this.aspectRatio = 16 / 9,
      this.controls = true,
      this.playbackEventListener,
      required this.onFullscreenChange,
      this.onError})
      : super(key: key);

  @override
  State<VdoStyledPlayer> createState() =>
      _VdoStyledPlayerState(playbackEventListener);
}

class _VdoStyledPlayerState extends State<VdoStyledPlayer> {
  bool _isFullScreenMode = false;
  MethodChannel? _methodChannel;
  PlaybackEventListener? playbackEventListener;
  final Completer<VdoPlayerController> _controller =
      Completer<VdoPlayerController>();
  VdoPlayerController? vdoPlayerController;
  final String uiViewType = 'com.vdocipher.flutter/vdoplayerui';
  bool _playerLoaded = false;
  VdoError? _vdoError;
  Orientation? initialOrientation;

  _VdoStyledPlayerState(this.playbackEventListener);

  @override
  Widget build(BuildContext context) {
    if (initialOrientation == null)
      initialOrientation = MediaQuery.of(context).orientation;
    return WillPopScope(
        child: Stack(
          children: [
            _getAndroidPlayerWidget(),
            _playerLoaded
                ? SizedBox.shrink()
                : Positioned.fill(
                    child: Container(
                      color: (vdoPlayerController?.value.mediaInfo == null) ? Colors.black : Colors.transparent,
                      child: Center(
                          child: _vdoError == null
                              ? ((widget.controls && vdoPlayerController?.value.mediaInfo == null)
                                  ? Container(
                                      width: 50,
                                      height: 50,
                                      child: CircularProgressIndicator(
                                        color: Colors.white,
                                        strokeWidth: 3,
                                      ),
                                    )
                                  : SizedBox.shrink())
                              : InkWell(
                                  onTap: () {
                                    vdoPlayerController?.load(widget.embedInfo);
                                  },
                                  child: Column(
                                    crossAxisAlignment:
                                        CrossAxisAlignment.center,
                                    mainAxisSize: MainAxisSize.min,
                                    children: [
                                      Icon(
                                        Icons.error,
                                        color: Colors.white,
                                      ),
                                      SizedBox(
                                        height: 5,
                                      ),
                                      Padding(
                                        padding: const EdgeInsets.all(8.0),
                                        child: Text(
                                          Utils.getErrorDescription(_vdoError!),
                                          textAlign: TextAlign.center,
                                          style: TextStyle(color: Colors.white),
                                        ),
                                      ),
                                    ],
                                  ),
                                )),
                    ),
                  ),
          ],
        ),
        onWillPop: () async {
          if (!widget.controls) return true;
          if (_isFullScreenMode && initialOrientation == Orientation.portrait) {
            _portraitScreen();
            return false;
          } else {
            return true;
          }
        });
  }

  @override
  void dispose() async {
    super.dispose();
    VdoPlayerController controller = await _controller.future;
    controller.dispose();
  }

  void _portraitScreen() {
    SystemChrome.setEnabledSystemUIMode(SystemUiMode.manual,
        overlays: SystemUiOverlay.values);
    SystemChrome.setPreferredOrientations([DeviceOrientation.portraitUp]);
  }

  _getAndroidPlayerWidget() {
    return _getAndroidView();
  }

  _getAndroidView() {
    return PlatformViewLink(
      viewType: uiViewType,
      surfaceFactory:
          (BuildContext context, PlatformViewController controller) {
        return AndroidViewSurface(
          controller: controller as AndroidViewController,
          gestureRecognizers: const <Factory<OneSequenceGestureRecognizer>>{},
          hitTestBehavior: PlatformViewHitTestBehavior.opaque,
        );
      },
      onCreatePlatformView: (PlatformViewCreationParams params) {
        return PlatformViewsService.initExpensiveAndroidView(
          id: params.id,
          viewType: uiViewType,
          layoutDirection: TextDirection.ltr,
          creationParams: {'showControls': widget.controls, 'enablePip': widget.embedInfo.embedInfoOptions?.enablePip ?? false},
          creationParamsCodec: StandardMessageCodec(),
        )
          ..addOnPlatformViewCreatedListener(
              _onPlatformViewCreated(params.onPlatformViewCreated))
          ..create();
      },
    );
  }

  _onPlatformViewCreated(Function platformViewCreatedCallback) {
    return ((int id) {
      _methodChannel = MethodChannel('com.vdocipher.flutter.vdoplayer_$id');
      _methodChannel!
          .setMethodCallHandler((call) => _handlePlatformMethodCall(call, id));
      platformViewCreatedCallback(id);
    });
  }

  Future<dynamic> _handlePlatformMethodCall(MethodCall call, int id) async {
    switch (call.method.toString()) {
      case "onPlatformPlayerCreated":
        setState(() {
          final VdoPlayerController vdoPlayerController =
              new VdoPlayerController(_methodChannel,
                  EventChannel("com.vdocipher.flutter.vdoplayer.events_$id"));
          _controller.complete(vdoPlayerController);
          this.vdoPlayerController = vdoPlayerController;
          vdoPlayerController.init();
          widget.onPlayerCreated(vdoPlayerController);
        });
        break;
      case "onProgress":
        playbackEventListener?.onProgress(call.arguments);
        break;
      case "onBufferUpdate":
        playbackEventListener?.onBufferUpdate(call.arguments);
        break;
      case "onPlaybackSpeedChanged":
        playbackEventListener?.onPlaybackSpeedChanged(call.arguments);
        break;
      case "onLoading":
        setState(() {
          _playerLoaded = false;
          _vdoError = null;
        });
        Map<Object?, Object?> arguments = call.arguments;
        EmbedInfo embedInfo = EmbedInfo.fromMap(arguments);
        playbackEventListener?.onLoading(embedInfo);
        break;
      case "onLoaded":
        Map<Object?, Object?> arguments = call.arguments;
        EmbedInfo embedInfo = EmbedInfo.fromMap(arguments);
        playbackEventListener?.onLoaded(embedInfo);
        setState(() {
          _playerLoaded = true;
          _vdoError = null;
        });
        break;
      case "onLoadError":
        Map<Object?, Object?> embedInfoMap = call.arguments['embedInfo'];
        Map<Object?, Object?> errorDescription =
            call.arguments['errorDescription'];
        EmbedInfo embedInfo = EmbedInfo.fromMap(embedInfoMap);
        VdoError vdoError = VdoError.fromMap(errorDescription);
        setState(() {
          _playerLoaded = false;
          _vdoError = vdoError;
        });
        if (widget.onError != null) widget.onError!(vdoError);
        playbackEventListener?.onLoadError(embedInfo, vdoError);
        break;
      case "onMediaEnded":
        Map<Object?, Object?> arguments = call.arguments;
        EmbedInfo embedInfo = EmbedInfo.fromMap(arguments);
        playbackEventListener?.onMediaEnded(embedInfo);
        break;
      case "onError":
        Map<Object?, Object?> embedInfoMap = call.arguments['embedInfo'];
        Map<Object?, Object?> errorDescription =
            call.arguments['errorDescription'];
        EmbedInfo embedInfo = EmbedInfo.fromMap(embedInfoMap);
        VdoError vdoError = VdoError.fromMap(errorDescription);
        setState(() {
          _playerLoaded = false;
          _vdoError = vdoError;
        });
        if (widget.onError != null) widget.onError!(vdoError);
        playbackEventListener?.onError(embedInfo, vdoError);
        break;
      case "onFullscreenAction":
        if (widget.onFullscreenChange != null) {
          _isFullScreenMode = call.arguments;
          widget.onFullscreenChange!(call.arguments);
          if (_isFullScreenMode) {
            SystemChrome.setEnabledSystemUIMode(SystemUiMode.manual,
                overlays: [SystemUiOverlay.bottom]);
          }
        }
        break;
      default:
        throw MissingPluginException();
    }
  }
}

==> vdocipher_flutter-2.2.1.tar.gz: lib/src/views/vdo_styled_player.dart <==
import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';
import 'package:vdocipher_flutter/src/views/playback_event.dart';
import 'package:vdocipher_flutter/src/views/utils.dart';
import 'package:vdocipher_flutter/vdocipher_flutter.dart';

class VdoStyledPlayer extends StatefulWidget {
  final EmbedInfo embedInfo;
  final double aspectRatio;
  final Function(VdoError vdoError)? onError;
  final PlaybackEventListener? playbackEventListener;
  final Function(bool isFullscreen)? onFullscreenChange;
  final Function(VdoPlayerController vdoPlayerController) onPlayerCreated;
  final bool controls;

  VdoStyledPlayer(
      {Key? key,
      required this.embedInfo,
      required this.onPlayerCreated,
      this.aspectRatio = 16 / 9,
      this.controls = true,
      this.playbackEventListener,
      required this.onFullscreenChange,
      this.onError})
      : super(key: key);

  @override
  State<VdoStyledPlayer> createState() =>
      _VdoStyledPlayerState(playbackEventListener);
}

class _VdoStyledPlayerState extends State<VdoStyledPlayer> {
  bool _isFullScreenMode = false;
  MethodChannel? _methodChannel;
  PlaybackEventListener? playbackEventListener;
  final Completer<VdoPlayerController> _controller =
      Completer<VdoPlayerController>();
  VdoPlayerController? vdoPlayerController;
  final String uiViewType = 'com.vdocipher.flutter/vdoplayerui';
  bool _playerLoaded = false;
  VdoError? _vdoError;
  Orientation? initialOrientation;

  _VdoStyledPlayerState(this.playbackEventListener);

  @override
  Widget build(BuildContext context) {
    if (initialOrientation == null)
      initialOrientation = MediaQuery.of(context).orientation;
    return WillPopScope(
        child: Stack(
          children: [
            _getAndroidPlayerWidget(),
            _playerLoaded
                ? SizedBox.shrink()
                : Positioned.fill(
                    child: Container(
                      color: (vdoPlayerController?.value.mediaInfo == null)
                          ? Colors.black
                          : Colors.transparent,
                      child: Center(
                          child: _vdoError == null
                              ? ((widget.controls &&
                                      vdoPlayerController?.value.mediaInfo ==
                                          null)
                                  ? Container(
                                      width: 50,
                                      height: 50,
                                      child: CircularProgressIndicator(
                                        color: Colors.white,
                                        strokeWidth: 3,
                                      ),
                                    )
                                  : SizedBox.shrink())
                              : InkWell(
                                  onTap: () {
                                    vdoPlayerController?.load(widget.embedInfo);
                                  },
                                  child: Column(
                                    crossAxisAlignment:
                                        CrossAxisAlignment.center,
                                    mainAxisSize: MainAxisSize.min,
                                    children: [
                                      Icon(
                                        Icons.error,
                                        color: Colors.white,
                                      ),
                                      SizedBox(
                                        height: 5,
                                      ),
                                      Padding(
                                        padding: const EdgeInsets.all(8.0),
                                        child: Text(
                                          Utils.getErrorDescription(_vdoError!),
                                          textAlign: TextAlign.center,
                                          style: TextStyle(color: Colors.white),
                                        ),
                                      ),
                                    ],
                                  ),
                                )),
                    ),
                  ),
          ],
        ),
        onWillPop: () async {
          if (!widget.controls) return true;
          if (_isFullScreenMode && initialOrientation == Orientation.portrait) {
            _portraitScreen();
            return false;
          } else {
            return true;
          }
        });
  }

  @override
  void dispose() async {
    super.dispose();
    VdoPlayerController controller = await _controller.future;
    controller.dispose();
  }

  void _portraitScreen() {
    SystemChrome.setEnabledSystemUIMode(SystemUiMode.manual,
        overlays: SystemUiOverlay.values);
    SystemChrome.setPreferredOrientations([DeviceOrientation.portraitUp]);
  }

  _getAndroidPlayerWidget() {
    return _getAndroidView();
  }

  _getAndroidView() {
    return PlatformViewLink(
      viewType: uiViewType,
      surfaceFactory:
          (BuildContext context, PlatformViewController controller) {
        return AndroidViewSurface(
          controller: controller as AndroidViewController,
          gestureRecognizers: const <Factory<OneSequenceGestureRecognizer>>{},
          hitTestBehavior: PlatformViewHitTestBehavior.opaque,
        );
      },
      onCreatePlatformView: (PlatformViewCreationParams params) {
        return PlatformViewsService.initExpensiveAndroidView(
          id: params.id,
          viewType: uiViewType,
          layoutDirection: TextDirection.ltr,
          creationParams: {
            'showControls': widget.controls,
            'enablePip': widget.embedInfo.embedInfoOptions?.enablePip ?? false
          },
          creationParamsCodec: StandardMessageCodec(),
        )
          ..addOnPlatformViewCreatedListener(
              _onPlatformViewCreated(params.onPlatformViewCreated))
          ..create();
      },
    );
  }

  _onPlatformViewCreated(Function platformViewCreatedCallback) {
    return ((int id) {
      _methodChannel = MethodChannel('com.vdocipher.flutter.vdoplayer_$id');
      _methodChannel!
          .setMethodCallHandler((call) => _handlePlatformMethodCall(call, id));
      platformViewCreatedCallback(id);
    });
  }

  Future<dynamic> _handlePlatformMethodCall(MethodCall call, int id) async {
    switch (call.method.toString()) {
      case "onPlatformPlayerCreated":
        setState(() {
          final VdoPlayerController vdoPlayerController =
              new VdoPlayerController(_methodChannel,
                  EventChannel("com.vdocipher.flutter.vdoplayer.events_$id"));
          _controller.complete(vdoPlayerController);
          this.vdoPlayerController = vdoPlayerController;
          vdoPlayerController.init();
          widget.onPlayerCreated(vdoPlayerController);
        });
        break;
      case "onProgress":
        playbackEventListener?.onProgress(call.arguments);
        break;
      case "onBufferUpdate":
        playbackEventListener?.onBufferUpdate(call.arguments);
        break;
      case "onPlaybackSpeedChanged":
        playbackEventListener?.onPlaybackSpeedChanged(call.arguments);
        break;
      case "onLoading":
        setState(() {
          _playerLoaded = false;
          _vdoError = null;
        });
        Map<Object?, Object?> arguments = call.arguments;
        EmbedInfo embedInfo = EmbedInfo.fromMap(arguments);
        playbackEventListener?.onLoading(embedInfo);
        break;
      case "onLoaded":
        Map<Object?, Object?> arguments = call.arguments;
        EmbedInfo embedInfo = EmbedInfo.fromMap(arguments);
        playbackEventListener?.onLoaded(embedInfo);
        setState(() {
          _playerLoaded = true;
          _vdoError = null;
        });
        break;
      case "onLoadError":
        Map<Object?, Object?> embedInfoMap = call.arguments['embedInfo'];
        Map<Object?, Object?> errorDescription =
            call.arguments['errorDescription'];
        EmbedInfo embedInfo = EmbedInfo.fromMap(embedInfoMap);
        VdoError vdoError = VdoError.fromMap(errorDescription);
        setState(() {
          _playerLoaded = false;
          _vdoError = vdoError;
        });
        if (widget.onError != null) widget.onError!(vdoError);
        playbackEventListener?.onLoadError(embedInfo, vdoError);
        break;
      case "onMediaEnded":
        Map<Object?, Object?> arguments = call.arguments;
        EmbedInfo embedInfo = EmbedInfo.fromMap(arguments);
        playbackEventListener?.onMediaEnded(embedInfo);
        break;
      case "onError":
        Map<Object?, Object?> embedInfoMap = call.arguments['embedInfo'];
        Map<Object?, Object?> errorDescription =
            call.arguments['errorDescription'];
        EmbedInfo embedInfo = EmbedInfo.fromMap(embedInfoMap);
        VdoError vdoError = VdoError.fromMap(errorDescription);
        setState(() {
          _playerLoaded = false;
          _vdoError = vdoError;
        });
        if (widget.onError != null) widget.onError!(vdoError);
        playbackEventListener?.onError(embedInfo, vdoError);
        break;
      case "onFullscreenAction":
        if (widget.onFullscreenChange != null) {
          _isFullScreenMode = call.arguments;
          widget.onFullscreenChange!(call.arguments);
          if (_isFullScreenMode) {
            SystemChrome.setEnabledSystemUIMode(SystemUiMode.manual,
                overlays: [SystemUiOverlay.bottom]);
          }
        }
        break;
      default:
        throw MissingPluginException();
    }
  }
}
